Re: [O] export to org, header args disappear

2014-05-21 Thread Aaron Ecay
Hello Bastien and Brady,

The babel/export interface does not attempt to manage the header args
when it rewrites source blocks.  I think this code is pretty subtle.
Check out the (let (... (replacement ...)) ...) code in
‘org-babel-exp-process-buffer’ and the attached patch which fixes the
problem (superficially; I’m not sure if it’s the correct fundamental
approach).

From 7faf58afa659cf63042464dbd15ad62239416832 Mon Sep 17 00:00:00 2001
From: Aaron Ecay aarone...@gmail.com
Date: Wed, 21 May 2014 01:58:18 -0400
Subject: [PATCH] ox-org: fix export of source blocks with header args

---
 lisp/ob-exp.el  | 52 +
 testing/lisp/test-ob-exp.el |  6 +++---
 2 files changed, 32 insertions(+), 26 deletions(-)

diff --git a/lisp/ob-exp.el b/lisp/ob-exp.el
index 220a3c3..ce45d84 100644
--- a/lisp/ob-exp.el
+++ b/lisp/ob-exp.el
@@ -311,7 +311,7 @@ The function respects the value of the :exports header argument.
 	 (org-babel-exp-code info)
 
 (defcustom org-babel-exp-code-template
-  #+BEGIN_SRC %lang%switches%flags\n%body\n#+END_SRC
+  #+BEGIN_SRC %lang%switches%params\n%body\n#+END_SRC
   Template used to export the body of code blocks.
 This template may be customized to include additional information
 such as the code block name, or the values of particular header
@@ -322,7 +322,7 @@ and the following %keys may be used.
  name -- the name of the code block
  body -- the body of the code block
  switches -- the switches associated to the code block
- flags - the flags passed to the code block
+ params  the parameters passed to the code block
 
 In addition to the keys mentioned above, every header argument
 defined for the code block may be used as a key and will be
@@ -332,27 +332,33 @@ replaced with its value.
 
 (defun org-babel-exp-code (info)
   Return the original code block formatted for export.
-  (setf (nth 1 info)
-	(if (string= strip-export (cdr (assoc :noweb (nth 2 info
-	(replace-regexp-in-string
-	 (org-babel-noweb-wrap)  (nth 1 info))
-	  (if (org-babel-noweb-p (nth 2 info) :export)
-	  (org-babel-expand-noweb-references
-	   info org-babel-exp-reference-buffer)
-	(nth 1 info
-  (org-fill-template
-   org-babel-exp-code-template
-   `((lang  . ,(nth 0 info))
- (body  . ,(org-escape-code-in-string (nth 1 info)))
- (switches . ,(let ((f (nth 3 info)))
-		  (and (org-string-nw-p f) (concat   f
- (flags . ,(let ((f (assq :flags (nth 2 info
-		   (and f (concat   (cdr f)
- ,@(mapcar (lambda (pair)
-		 (cons (substring (symbol-name (car pair)) 1)
-		   (format %S (cdr pair
-	   (nth 2 info))
- (name  . ,(or (nth 4 info) )
+  ;; Here we assume that point is in the source block, an assumption
+  ;; we inherit from `org-babel-exp-src-block'.
+  (let* ((sb (org-element-at-point))
+	 (params (org-element-property :parameters sb)))
+(setf (nth 1 info)
+	  (if (string= strip-export (cdr (assoc :noweb (nth 2 info
+	  (replace-regexp-in-string
+	   (org-babel-noweb-wrap)  (nth 1 info))
+	(if (org-babel-noweb-p (nth 2 info) :export)
+		(org-babel-expand-noweb-references
+		 info org-babel-exp-reference-buffer)
+	  (nth 1 info
+(org-fill-template
+ org-babel-exp-code-template
+ `((lang  . ,(nth 0 info))
+   (body  . ,(org-escape-code-in-string (nth 1 info)))
+   (switches . ,(let ((f (nth 3 info)))
+			(and (org-string-nw-p f) (concat   f
+   (flags . ,(let ((f (assq :flags (nth 2 info
+		 (and f (concat   (cdr f)
+   (params . ,(when (and params (not (string= params )))
+		  (concat   params)))
+   ,@(mapcar (lambda (pair)
+		   (cons (substring (symbol-name (car pair)) 1)
+			 (format %S (cdr pair
+		 (nth 2 info))
+   (name  . ,(or (nth 4 info) ))
 
 (defun org-babel-exp-results (info type optional silent hash)
   Evaluate and return the results of the current code block for export.
diff --git a/testing/lisp/test-ob-exp.el b/testing/lisp/test-ob-exp.el
index 1fe810b..b5738d5 100644
--- a/testing/lisp/test-ob-exp.el
+++ b/testing/lisp/test-ob-exp.el
@@ -289,7 +289,7 @@ Here is one at the end of a line. =2=
 : 2
 
 #+NAME: src1
-#+BEGIN_SRC emacs-lisp
+#+BEGIN_SRC emacs-lisp :exports both
 \(+ 1 1)
 #+END_SRC
 (org-test-with-temp-text
@@ -316,9 +316,9 @@ Here is one at the end of a line. =2=
   Test exporting a source block with a flag.
   (should
(string-match
-\\`#\\+BEGIN_SRC emacs-lisp -some-flag$
+\\`#\\+BEGIN_SRC emacs-lisp -x$
 (org-test-with-temp-text
-	#+BEGIN_SRC emacs-lisp :flags -some-flag\n\(+ 1 1)\n#+END_SRC
+	#+BEGIN_SRC emacs-lisp -x\n\(+ 1 1)\n#+END_SRC
   (org-export-execute-babel-code)
   (buffer-string)
 
-- 
1.9.3


--
Aaron Ecay


[O] temporarily un-ignoring scheduled tasks in global todo list

2014-05-21 Thread Christoph Groth
Hi,

I like to have

(setq org-agenda-todo-ignore-scheduled 'all)
(setq org-agenda-todo-ignore-deadlines 'all)
(setq org-agenda-tags-todo-honor-ignore-options t)

but sometimes I would like to search for some item that I know that is
scheduled somewhere into the future.  Or I want to verify whether some
item exists.

What would be the best way to temporarily show all tasks?  I am thinking
of writing a function that calls org-agenda with the above variables
temporarily set to the default values.  (That should be possible in
elisp, but I do not yet know how.)  Is there a better way?

Alternatively, one could always show all items in the global todo list,
but somehow mark the already scheduled ones.  Orgmode does not seem to
allow for something like this out-of-the-box, though.

Thanks,
Christoph




Re: [O] Preview tikz in org-mode (reduce margins of produced images)

2014-05-21 Thread Leu Zhe
Hi Nick,

Thanks you for your help.

Finally I found a solution by referring the examples in texample.net.
I just replaced the \documentclass{article} to
 documentclass[varwidth]{standalone},
then it works perfectly.

I am not familiar enriched-mode, too.
It is also very strange that why i can not receive the email in my gmail...

Thank you anyway.

Leu


Re: [O] Quoting functions with ' vs #'

2014-05-21 Thread Bastien
Hi Aaron,

Aaron Ecay aarone...@gmail.com writes:

 Commit a5686d87 (link[1]) changes several uses of #' to '.  Is this org
 “house style”?

Not really.  My decision for this can be sumed up like this:

#+begin_src elisp
(defun i-give-a-warning () (mapc 'does-exist '(1 2 3)))
(defun i-do-not () (mapc #'maybe-problematic-for-compilation '(1 2 3)))
#+end_src

But I don't feel strongly about that, except for #'(lambda ...) which
is just redondant, if not misleading.

2 cts,

-- 
 Bastien



Re: [O] Insert calc vector directly into spreadsheet cells?

2014-05-21 Thread Michael Brand
Hi Steven

 Steven Adrian sadr...@acumeniacal.com writes:
 #+TBLFM: @1$1..@1$10=index(10)

 But the formula above just puts the whole vector in each cell. Can anyone
 tell me how to put the vector values in individual cells?

The vector elements can be accessed with Calc subscr() and Org field
coordinates:
http://orgmode.org/manual/References.html

| 1 | 2 | 3 | 4 | 5 | 6 | 7 | 8 | 9 | 10 |
#+TBLFM: @1$1..@1$10 = subscr(index(10), $#)

In a TBLFM I would not use Calc vector functions like index() but a
calculation of $#, here simply f(x) = x:

| 1 | 2 | 3 | 4 | 5 | 6 | 7 | 8 | 9 | 10 |
#+TBLFM: @1$1..@1$10 = $#

Or is there an interesting Calc vector function that is not easy to
mimic?

Michael



Re: [O] ob-lua.el

2014-05-21 Thread Bastien
Hi Dieter,

Dieter Schoen die...@schoen.or.at writes:

 i have just sent the email to ass...@gnu.org to start the process.

Great -- let us know how it goes (can take one month.)

In the meantime, you can fix small things like the authors of the
package, the owner of the copyright and such.

Thanks for this contribution!

-- 
 Bastien



[O] Integration of Groupware calendar solutions like CalendarTree

2014-05-21 Thread Karl Voit
Hi!

I just stumbled over CalendarTree[1] which is a service that
promotes calendar events to multiple kind of calendar tools and
services such as Outlook, Google Calendar and so on.

I wondered how easy somebody could implement support for Org-mode?
And I wondered if this is a possible way to add a groupware-layer to
Org-mode?

Org-mode is very great for me. But it's an island when it comes to
sharing events and so forth. :-(


  1. https://www.calendartree.com/HowItWorks
-- 
mail|git|SVN|photos|postings|SMS|phonecalls|RSS|CSV|XML to Org-mode:
get Memacs from https://github.com/novoid/Memacs 

https://github.com/novoid/extract_pdf_annotations_to_orgmode + more on github




Re: [O] An org password manager

2014-05-21 Thread Bastien
Hi Jorge,

jorge.a.alf...@gmail.com (Jorge A. Alfaro-Murillo) writes:

 If there is interest from the community this can also go to
 /contrib.

I think this would be a nice contribution.

Can you send a patch against the current master branch to add the
code in the contrib/lisp/ directory?

Thanks a lot!

-- 
 Bastien



Re: [O] Preview tikz in org-mode (reduce margins of produced images)

2014-05-21 Thread Bastien
Hi Leu,

Leu Zhe lzhe...@gmail.com writes:

 I just replaced the \documentclass{article} to  documentclass
 [varwidth]{standalone},
 then it works perfectly.

Thanks for sharing this trick, hard to find, so even more valuable
when made public.

-- 
 Bastien



[O] m-ret no indent

2014-05-21 Thread Samuel Wales
in recent maint, m-ret between paragraphs inserts at top level.  i
don't recall this occurring before.



Re: [O] m-ret no indent

2014-05-21 Thread Bastien
Hi Samuel,

Samuel Wales samolog...@gmail.com writes:

 in recent maint, m-ret between paragraphs inserts at top level.  i
 don't recall this occurring before.

This should have been fixed this night, can you pull again and
double-check?

Thanks,

-- 
 Bastien



Re: [O] wish: provide flush_right/right_aligned text rendering directive

2014-05-21 Thread Gregor Zattler
Hi Bastien,
* Bastien b...@gnu.org [21. May. 2014]:
 Gregor Zattler telegr...@gmx.net writes:
 I wish for a #+BEGIN_FLUSH_RIGHT (#+BEGIN_RIGHT_ALIGNED)
 directive in order to render text right flushed (right aligned)
 in export backends.
 
 Just out of curiosity, what backend do you need this for?

In the use case for which I wished this is ASCII/Latin-1/UTF-8
export.  I write letters in org-mode and right flush would be
useful for the letter header part with my address.

If I have to cooperate with people who do not know how to
collectively produce plain text documents, I use the html and odt
backends.


Ciao, Gregor
-- 
 -... --- .-. . -.. ..--.. ...-.-



Re: [O] Org based websites w/o export

2014-05-21 Thread Detlef Steuer
Am Tue, 20 May 2014 13:43:20 +0200
schrieb Bernd Haug bernd.h...@xaidat.com:

 On 19 May 2014 19:58, Ken Mankoff mank...@gmail.com wrote:
  Jr works by having javascript render the markdown to HTML. That is,
  you write markdown, upload markdown w/o running a generator, and the
  generator runs in the browser of the viewer.
 
  This is efficient for the server (simpler pages) and author (no
  need to run a static site generator), but may be globally
  inefficient for a popular site (many browser doing rendering).
 
 I'd phrase this point more strongly:
 The whole concept of intensive client-side rendering
 is fashionable, but an eminently bad idea from a
 number of perspectives.

Thank you for this post! This fashion together with the love for an
unbearable amount of whitespace instead of content on modern websites
is irritating. (Ok, at least for me.) 

If you really suffer from converting .md to .html  just automate it with some
makefile and scp magic. You can hack away like in the case of client site 
rendering and you don´t imply the consequences Bernd outlines.

On the server side compression of static pages should help a lot.
(There is a trade off between energy demand and compression of course,
but .gz decompression is very efficient.)

 
 I ran my list past Ken and he encouraged me to post them (thanks), so
 here goes:
 
 1) UX:
 
 Rendering in the browser's rendering engine is always faster than
 rendering in JS and then in the browser's rendering engine. Speed
 matters.

Think about the runtime and longevity of your mobile phone.
For most this should be a killer argument. :-)

Regards
Detlef 



 
 2) Engineering (l'art pour l'art):
 
 Not caching the most eminently cacheable thing on Earth, the rendering
 of static web pages, makes baby Dijkstra cry.
 
 3) Economics (egoistical):
 
 Search engines are optimized for interpreting and presenting HTML. If
 you want to be found, have your content in HTML.
 
 4) Economics (global):
 
 Electricity ain't free; why spend it many times over even if it's not
 you doing the spending?
 
 5) Ecology
 
 There are impacts to wasting power beyond its monetary price.
 
 
 
 So, enough with the criticism. How to constructively approach this?
 
 If the size difference between HTML and MD makes a difference for
 your bandwidth cost, maybe consider just precompressing your files
 offline (this, too, can be done prior to uploading…) and teaching your
 web server that for files x.html, deliver x.html.gz as a pre
 compressed stream first if available.
 
 Cheers, Bernd
 
 





Re: [O] Org-hide face leaking out to org-columns view

2014-05-21 Thread Nikolai Weibull
On Wed, May 21, 2014 at 4:35 AM, Bastien b...@gnu.org wrote:
 Hi Nikolai,

 Nikolai Weibull n...@disu.se writes:

 It seems that if you use

 #+STARTUP: indent

 the org-hide face used for the hidden stars will remain when using the
 org-columns view, resulting on, in my case, white on gray.

 To clarify, this leaks out over the whole item, not just the stars,
 making the whole item column hard to read.

 Is there a workaround to this that I’m not thinking of?

 I'm not sure I understand the problem.

 Can you send a small picture?

 In any case, here with Org 8.2.6 I don't see a problem: both the
 indentation and the hiding of the stars are canceled when using the
 column view.

Yes, the hiding of the stars is cancelled, but it seems that the
org-hide face is still being applied and leaking unto the whole
headline.  I got around this by adjusting the org-column face.



Re: [O] C-c C-e h h (export to html)

2014-05-21 Thread Dave Pawson
On 20 May 2014 20:47, Bastien b...@gnu.org wrote:

 Yes, you need `C-c C-e h h' with Org 8.0.

Odd. With my full .emacs file.
C-c C-e h (and nothing happens at all)
h again and (if it's working) I get the message 'Wrote /dir/file.html'

With no .emacs the first h produces message
HTML export done, pushed to kill ring and clipboard
h again and the h is 'entered' into the current buffer?

regards






-- 
Dave Pawson
XSLT XSL-FO FAQ.
Docbook FAQ.
http://www.dpawson.co.uk



Re: [O] [PATCH] Make the point visible when jumping to the mark

2014-05-21 Thread Ian Kelling
Bastien b...@gnu.org writes:

 Hi Ian,

 Ian Kelling i...@iankelling.org writes:

 I posted this patch in September. It seems it was forgotten.

 I missed it as the time.

 I posted it again on April 30th, nothing yet.  I also have another
 patch thats been sitting on the list for a few weeks now after
 having a discussion and a positive response.

 Yes, in http://article.gmane.org/gmane.emacs.orgmode/86050

 Did you receive the FSF confirmation for your copyright assignment?
 That's the information we need before applying the patches.

Yes, I've got the confirmation. All set.

 I'd like to do a git pull and find my patches applied at some point,
 and I'm wondering if/when that will happen. And is there anything I
 can do to help?

 If the process is completed let us know and we will move on.

 Thanks!

Great to hear. Yes, all completed.

Thanks,
Ian





[O] Preserve formatting when copy/pasting from HTML

2014-05-21 Thread Tory S. Anderson
We often read online articles with headings and sometimes subheadings. They may 
also include bold, italic, and hyperlinks, all of which are supported by Org. 
Is there any way to preserve this formatting if I copy-paste into org/emacs, 
the same way it's preserved when I paste into Word or into a Google 
Document/email? Or is this fundamentally difficult in emacs? It would be a 
tremendous feature. 

- Tory



Re: [O] Org-hide face leaking out to org-columns view

2014-05-21 Thread Bastien
Hi Nikolai,

Nikolai Weibull n...@disu.se writes:

 Yes, the hiding of the stars is cancelled, but it seems that the
 org-hide face is still being applied and leaking unto the whole
 headline.  I got around this by adjusting the org-column face.

Thanks for the follow-up -- I'd still be interested by a screenshot to
better understand what happens with the default face.  Thanks in advance,

-- 
 Bastien



Re: [O] temporarily un-ignoring scheduled tasks in global todo list

2014-05-21 Thread Bastien
Hi Christoph,

Christoph Groth christ...@grothesque.org writes:

 (setq org-agenda-todo-ignore-scheduled 'all)
 (setq org-agenda-todo-ignore-deadlines 'all)
 (setq org-agenda-tags-todo-honor-ignore-options t)

 but sometimes I would like to search for some item that I know that is
 scheduled somewhere into the future.  Or I want to verify whether some
 item exists.

The way I would do this is by defining a separate agenda custom view
with different values for the variables above.

M-: (info (Org)Setting options) RET will give you details on how to
set the options for each view.

HTH,

-- 
 Bastien



Re: [O] C-c C-e h h (export to html)

2014-05-21 Thread Bastien
Hi Dave,

Dave Pawson dave.paw...@gmail.com writes:

 On 20 May 2014 20:47, Bastien b...@gnu.org wrote:

 Yes, you need `C-c C-e h h' with Org 8.0.

 Odd. With my full .emacs file.
 C-c C-e h (and nothing happens at all)

Because the keystroke is incomplete.

It needs to be one of these:

C-c C-e h h
C-c C-e h H
C-c C-e h o

 h again and (if it's working) I get the message 'Wrote
 /dir/file.html'

Yes.

 With no .emacs the first h produces message
 HTML export done, pushed to kill ring and clipboard
 h again and the h is 'entered' into the current buffer?

Because with no .emacs you are relying on the builtin Emacs version of
Org, which is certainly 7.8.11.  Try M-x org-version RET in both cases
and you will see the difference.

HTH,

-- 
 Bastien



Re: [O] wish: provide flush_right/right_aligned text rendering directive

2014-05-21 Thread Bastien
Hi Gregor,

Gregor Zattler telegr...@gmx.net writes:

 In the use case for which I wished this is ASCII/Latin-1/UTF-8
 export.  I write letters in org-mode and right flush would be
 useful for the letter header part with my address.

 If I have to cooperate with people who do not know how to
 collectively produce plain text documents, I use the html and odt
 backends.

Thanks -- I don't have time for this right now, but maybe someone
will.  I noted it as a feature request in my local TODO list.  Please
use [FR] in your subject line for next feature requests.

Best,

-- 
 Bastien



Re: [O] Integration of Groupware calendar solutions like CalendarTree

2014-05-21 Thread Bastien
Hi Karl,

Karl Voit devn...@karl-voit.at writes:

 I wondered how easy somebody could implement support for Org-mode?

Maybe you can ping the calendartree.com for this?

They get paid for their work and would certainly love to get a larger
customer base by adding such a cool feature.  And they have a better
knowledge of how their system works, I didn't register a free account
just for checking further.  Nothing to lose by asking them I guess.

Thanks,

-- 
 Bastien



Re: [O] An org password manager

2014-05-21 Thread Michael Albinus
Bastien b...@gnu.org writes:

 Hi Jorge,

Hi,

 If there is interest from the community this can also go to
 /contrib.

 I think this would be a nice contribution.

A useful feature would be an auth-source backend, See (info (auth))
By this, other packages (like Gnus or Tramp) would profit from the
password manager directly.

Best regards, Michael.



Re: [O] Preserve formatting when copy/pasting from HTML

2014-05-21 Thread Bastien
Hi Tory,

torys.ander...@gmail.com (Tory S. Anderson) writes:

 We often read online articles with headings and sometimes
 subheadings. They may also include bold, italic, and hyperlinks, all
 of which are supported by Org. Is there any way to preserve this
 formatting if I copy-paste into org/emacs, the same way it's preserved
 when I paste into Word or into a Google Document/email? Or is this
 fundamentally difficult in emacs? It would be a tremendous feature.

It would be easy to code something that sometimes works, with a dumb
parsing of the most common HTML tags and rendering into Org syntax.
But this would be really fragile and doing it right is fundamentally
difficult.

I'd love to see someone proves me I'm too pessimistic, though.

Best,

-- 
 Bastien



Re: [O] export to org, header args disappear

2014-05-21 Thread Bastien
Hi Aaron,

Aaron Ecay aarone...@gmail.com writes:

 The babel/export interface does not attempt to manage the header args
 when it rewrites source blocks.  I think this code is pretty subtle.
 Check out the (let (... (replacement ...)) ...) code in
 ‘org-babel-exp-process-buffer’ and the attached patch which fixes the
 problem (superficially; I’m not sure if it’s the correct fundamental
 approach).

I'm not sure either this is fundamentally correct, but it works fine
for me.  I'll let Eric decide on whether this can go to master or not,
and if Eric does not have the time, just go ahead and push the change.

Thanks for this!

-- 
 Bastien



Re: [O] Preserve formatting when copy/pasting from HTML

2014-05-21 Thread Albert Krewinkel
torys.ander...@gmail.com (Tory S. Anderson) writes:

 We often read online articles with headings and sometimes subheadings. They
 may also include bold, italic, and hyperlinks, all of which are supported by
 Org. Is there any way to preserve this formatting if I copy-paste into
 org/emacs, the same way it's preserved when I paste into Word or into a Google
 Document/email? Or is this fundamentally difficult in emacs? It would be a
 tremendous feature.

A suggestion for a workaround: You might get decent results using
Pandoc[1] and pandoc-mode[2].  Pandoc can parse HTML and convert it to
org-mode markup.  There is also a helpful answer on stackexchange[3]
(just replace markdown with org).  You might be able to use the above
tools to integrate the mentioned techniques into org's capture mechanism.

HTH,
Albert

[1] http://johnmacfarlane.net/pandoc
[2] https://github.com/joostkremers/pandoc-mode
[3] http://unix.stackexchange.com/questions/78395/

-- 
Albert Krewinkel
GPG: 8eed e3e2 e8c5 6f18 81fe  e836 388d c0b2 1f63 1124



Re: [O] org-review-schedule

2014-05-21 Thread Bastien
Hi Alan,

Alan Schmitt alan.schm...@polytechnique.org writes:

 Thank you for the opportunity. I've been getting spoiled by the use of
 github (to track issues, and to have documentation at the same place
 than the code). I'm wondering if there is a way to have the code both on
 github and in the contrib directory. Is there any current package doing
 it?

No.  And that's why I'm considering the migration of contributed
packages into a new Org ELPA, where sync'ing the Org ELPA package
from another repository would be possible.  A win-win situation
for everyone.

 Regarding the documentation, by the way, where should one put it for
 contrb packages? On worg?

Yes.  You can even add documentation for stuff that is not in contrib
but available on github or on some other repository service.

 It will get exposure when we announce it for the upcoming 8.3 release.

 This is an important matter to take into account indeed 

:)

-- 
 Bastien



[O] Moving footnotes

2014-05-21 Thread Leonard Randall
Hi all,
One of the things I really like about org-mode is the ability to quickly
move material between projects. For instance, I sometimes write material as
a conference paper and want to use some sections in my thesis. I also like
to keep a file with old chapter drafts for later reference (I could just
use git for this, but keeping an old-drafts file around makes some jobs
more convenient). One issue that I am running into is that when I move
material with org-refile, footnotes defined in the Footnote section do not
move with it.  Additionally, if I try to export a subtree as an org buffer,
it does not take footnote definitions with it.

The obvious workaround for both problems is to define footnotes inline.
Another option (the one that I am using currently) is to set
org-footnote-section to nil, and to set org-footnote-auto-label to 'random.
This way footnotes are kept at the bottom of the section, so they move with
refile, and they have randomly generated names, so they won't conflict with
any footnote definitions in the destination file.

This solution works, but I wondered if there was any way to get org-refile
and org-export-org to take footnotes definitions with them, wherever they
are located.
With org-export-org, this seems especially important as backends are
supposed to faithfully export footnotes with their definitions.

Additionally, is there a way to easily convert numbered footnotes to
randomly named footnotes?

Thanks,

 Leonard


Re: [O] temporarily un-ignoring scheduled tasks in global todo list

2014-05-21 Thread Christoph Groth
Thanks Bastien, this works!

There doesn't seem to be an easy way to make a custom agenda view that
only shows todo items that are scheduled for the future.  Or am I wrong?

Christoph




Re: [O] [PATCH] Improve usage of odt content templates

2014-05-21 Thread Nicolas Goaziou
Hello,

Christian Kellermann ck...@pestilenz.org writes:

 I first thought about using ODT_STYLES_FILE in the list form and
 pick out the content.xml from there, but maybe that's a bit unexpected
 as one might use a different content than from the style.

 But the control flow as it is now would need to be refactored to
 make this a nice patch too.

 I shall resend this patch with proper docstrings and manual patches
 if you like.

Please do.

 I think this is a more general issue: should we implement an
 
   #+OPTIONS: title:nil
 
 feature? I think it makes some sense since we already have date:nil and
 author:nil. In any case, keywords are not meant to be used for booleans.
 This should be an OPTIONS item.

 I don't feel qualified to decide on this. I can provide the needed
 patches though.

Introducing the item is easy, but making something out of it in each
back-end is not, as it requires to define what title:nil means there. In
particular, should it be an empty title or something else?

For example, ascii back-end provides a banner as its title. Should
title:nil remove the title from the banner or should it remove the
banner altogether, thus overriding date:t and author:t items.

Likewise, should title:nil insert \title{} in a LaTeX document header,
remove the \maketitle{} line, or perhaps, both?

It seems that you answered to that question regarding ODT back-end
though.

WDYT?


Regards,

-- 
Nicolas Goaziou



Re: [O] org-review-schedule

2014-05-21 Thread Alan Schmitt
Hi Bastien,

On 2014-05-21 14:08, Bastien b...@gnu.org writes:

 Thank you for the opportunity. I've been getting spoiled by the use of
 github (to track issues, and to have documentation at the same place
 than the code). I'm wondering if there is a way to have the code both on
 github and in the contrib directory. Is there any current package doing
 it?

 No.  And that's why I'm considering the migration of contributed
 packages into a new Org ELPA, where sync'ing the Org ELPA package
 from another repository would be possible.  A win-win situation
 for everyone.

I've thought about this and I will try to go the ELPA route. Even if it
means less exposure, it seems to be conceptually closer to my vision of
this package (an add-on that does not need to add to the already huge
git repository).

 Regarding the documentation, by the way, where should one put it for
 contrb packages? On worg?

 Yes.  You can even add documentation for stuff that is not in contrib
 but available on github or on some other repository service.

It makes sense. I'll add writing a tutorial on worg on my todo list.

Thanks,

Alan



Re: [O] [PATCH] Make the point visible when jumping to the mark

2014-05-21 Thread Bastien
Hi Ian,

Please send me your public key so that I can give you access to the
org-mode and worg repositories.

Ian Kelling i...@iankelling.org writes:

 From 9191e4a364e251119cf8b7c72e41f6c0d09583f2 Mon Sep 17 00:00:00 2001
 Message-ID: 87ha5aqa93@treetowl.lan
 MIME-Version: 1.0
 Content-Type: text/plain

 *lisp/org.el: Advise commands which jump to the mark

The formatting of the Changelog message not good.

It should be

* org.el: Advise commands which jump to the mark.

See http://orgmode.org/worg/org-contribute.html and example in
the git logs.

 +(eval-after-load simple
 +  '(defadvice set-mark-command (after org-make-visible activate)
 + Make the point visible with `org-show-context'.
 + (org-mark-jump-unhide)))

Why this one?  The user don't want to use C-SPC in hidden parts.

 +(eval-after-load simple
 +  '(defadvice exchange-point-and-mark (after org-make-visible activate)
 + Make the point visible with `org-show-context'.
 + (org-mark-jump-unhide)))

 +(eval-after-load simple
 +  '(defadvice pop-global-mark (after org-make-visible activate)
 + Make the point visible with `org-show-context'.
 + (org-mark-jump-unhide)))

This two ones are good, yes.

Thanks,

-- 
 Bastien



Re: [O] [PATCH] Fix error prone babel table output format detection

2014-05-21 Thread Bastien
Hi Ian,

Ian Kelling i...@iankelling.org writes:

 Done. I was actually following the instructions in man git-format-patch by
 not attaching it before, but I will avoid that in future.

Applied, thanks.  I slightly rewrote the changelog message, please
have a look for further patches.

Thanks!

-- 
 Bastien



Re: [O] wish: provide flush_right/right_aligned text rendering directive

2014-05-21 Thread Nicolas Goaziou
Hello,

Bastien b...@gnu.org writes:

 Gregor Zattler telegr...@gmx.net writes:

 In the use case for which I wished this is ASCII/Latin-1/UTF-8
 export.  I write letters in org-mode and right flush would be
 useful for the letter header part with my address.

 Thanks -- I don't have time for this right now, but maybe someone
 will.  I noted it as a feature request in my local TODO list.  Please
 use [FR] in your subject line for next feature requests.

I don't know what you mean by this, but I don't think introducing a new
type of block in Org syntax is worth the trouble here.

Also, the feature is already available in some others back-ends, e.g.,
LaTeX, through a special block.

ISTM this is only related to `ascii' export back-end. So it could be
solved by a special block handled specially in there.


Regards,

-- 
Nicolas Goaziou



Re: [O] wish: provide flush_right/right_aligned text rendering directive

2014-05-21 Thread Bastien
Hi Nicolas,

Nicolas Goaziou n.goaz...@gmail.com writes:

 Also, the feature is already available in some others back-ends, e.g.,
 LaTeX, through a special block.

Mh, yes.  In other words,

#+begin_flushright
Hello
#+end_flushright

will be exported as

div class=flushright
  p
  Hello
  /p
/div

in HTML.

 ISTM this is only related to `ascii' export back-end. So it could be
 solved by a special block handled specially in there.

Yes, good idea.  Can you take care of it?

-- 
 Bastien



Re: [O] How to use ispell in org mode: goal is to skip source blocks

2014-05-21 Thread Bastien
Hi Grant,

Grant Rettke g...@wisdomandwonder.com writes:

 Working on large literate org documents takes a lot longer when ispell
 reports errors in the source
 code. My goal is to avoid spell checking anything inside the source
 blocks.

You can use this:

(add-to-list 'ispell-skip-region-alist '(#\\+begin_src. #\\+end_src))

HTH,

-- 
 Bastien



Re: [O] How to use ispell in org mode: goal is to skip source blocks

2014-05-21 Thread Igor Sosa Mayor
Bastien b...@gnu.org writes:

[...]

 You can use this:

 (add-to-list 'ispell-skip-region-alist '(#\\+begin_src. #\\+end_src))

wow, interesting... I was not aware of this feature. Thanks a lot!

-- 
:: Igor Sosa Mayor :: joseleopoldo1...@gmail.com ::
:: GnuPG: 0x1C1E2890   :: http://www.gnupg.org/  ::
:: jabberid: rogorido  ::::




Re: [O] New worg page: Publishing beamer slideshows and articles from one source

2014-05-21 Thread Bastien
Hi Suvayu,

Suvayu Ali fatkasuvayu+li...@gmail.com writes:

 BTW, the ignoreheading thing has been asked so many times, maybe I
 should put it in an FAQ.  But then, the content is more appropriate for
 org-hacks ... I'm undecided.  Any thoughts?

It's both a FAQ and a hack, perhaps put the answer in the FAQ and the
details in org-hacks?

-- 
 Bastien



Re: [O] new to drawers

2014-05-21 Thread Bastien
Hi Nick,

Nick Dokos ndo...@gmail.com writes:

 I thought so too, but when I tried it, I got the same result as Steven.
 I'll try to dig down a bit more.

Did you find something?
I cannot reproduce the OT problems here on master.

-- 
 Bastien



Re: [O] wish: provide flush_right/right_aligned text rendering directive

2014-05-21 Thread Nicolas Goaziou
Bastien b...@gnu.org writes:

 Yes, good idea.  Can you take care of it?

I can look into it.

What shall be the name of the block? latex uses raggedleft, html
flushright...


Regards,

-- 
Nicolas Goaziou



Re: [O] How to use ispell in org mode: goal is to skip source blocks

2014-05-21 Thread Bastien
Igor Sosa Mayor joseleopoldo1...@gmail.com writes:

 Bastien b...@gnu.org writes:

 [...]

 You can use this:

 (add-to-list 'ispell-skip-region-alist '(#\\+begin_src. #\\+end_src))

 wow, interesting... I was not aware of this feature. Thanks a lot!

Not really a FAQ, but useful, so I've added a note here:
http://orgmode.org/worg/org-faq.html#sec-22-4

-- 
 Bastien



Re: [O] How to use ispell in org mode: goal is to skip source blocks

2014-05-21 Thread Igor Sosa Mayor
Bastien b...@gnu.org writes:

 Not really a FAQ, but useful, so I've added a note here:
 http://orgmode.org/worg/org-faq.html#sec-22-4

good idea! This is a rather unknown feature, I have the impression... 

-- 
:: Igor Sosa Mayor :: joseleopoldo1...@gmail.com ::
:: GnuPG: 0x1C1E2890   :: http://www.gnupg.org/  ::
:: jabberid: rogorido  ::::




Re: [O] new to drawers

2014-05-21 Thread Nick Dokos
Bastien b...@gnu.org writes:

 Hi Nick,

 Nick Dokos ndo...@gmail.com writes:

 I thought so too, but when I tried it, I got the same result as Steven.
 I'll try to dig down a bit more.

 Did you find something?
 I cannot reproduce the OT problems here on master.

Sorry, I didn't - I ran out of time.

Nick




Re: [O] temporarily un-ignoring scheduled tasks in global todo list

2014-05-21 Thread Bastien
Hi Christoph,

Christoph Groth christ...@grothesque.org writes:

 There doesn't seem to be an easy way to make a custom agenda view that
 only shows todo items that are scheduled for the future.  Or am I wrong?

Use a TODO agenda view, and set `org-agenda-todo-ignore-scheduled' to
past within this custom agenda view.

HTH,

-- 
 Bastien



Re: [O] manipulating org-tables as matrices - operations on org-table in diagonal direction for columns and rows

2014-05-21 Thread Bastien
Hi Daniel,

Daniel Kiertscher d.kiertsc...@gmx.de writes:

 org-tables already support very helpful operations for manipulating
 the order of rows and columns. But we could implement some operations
 based on the concept of matrices, making org-tables even more usefull
 for drafting ideas using matrix layouts.
 Maybe you are interested in the operations I am suggesting and can
 help me to implement them.
 Maybe you have some questions or suggestions, improving or
 generalising this approach?
 Here are the first sketches of a part of the functions on org-table
 which I am missing for quite a while now.

Those are useful operations, but I doubt each of them is worth a
separate command and a new keybinding.  Because each function is
a combo of two commands that are already quite fast and accessible,
and -- at least for me -- it seems easier to type M-right M-up
instead of the related keystroke you suggest.

Another approach would be to use this for yourself for a while,
see what are the most useful commands, and see if their keybinding
makes it really worth adding them to the core of Org.

Thanks,

-- 
 Bastien



Re: [O] Org-hide face leaking out to org-columns view

2014-05-21 Thread Nikolai Weibull
On Wed, May 21, 2014 at 1:31 PM, Bastien b...@altern.org wrote:

 Nikolai Weibull n...@disu.se writes:

 Yes, the hiding of the stars is cancelled, but it seems that the
 org-hide face is still being applied and leaking unto the whole
 headline.  I got around this by adjusting the org-column face.

 Thanks for the follow-up -- I'd still be interested by a screenshot to
 better understand what happens with the default face.  Thanks in advance,

Here’s a screen-shot of how org-hide, which sets foreground to white, leaks.


Re: [O] wish: provide flush_right/right_aligned text rendering directive

2014-05-21 Thread Bastien
Nicolas Goaziou n.goaz...@gmail.com writes:

 What shall be the name of the block? latex uses raggedleft, html
 flushright...

Maybe

begin_justifyright
begin_justifyleft
begin_justifyfull

to reuse the Emacs terminology for text alignment?

-- 
 Bastien



Re: [O] Org-hide face leaking out to org-columns view

2014-05-21 Thread Nikolai Weibull
On Wed, May 21, 2014 at 3:48 PM, Nikolai Weibull n...@disu.se wrote:
 On Wed, May 21, 2014 at 1:31 PM, Bastien b...@altern.org wrote:

 Nikolai Weibull n...@disu.se writes:

 Yes, the hiding of the stars is cancelled, but it seems that the
 org-hide face is still being applied and leaking unto the whole
 headline.  I got around this by adjusting the org-column face.

 Thanks for the follow-up -- I'd still be interested by a screenshot to
 better understand what happens with the default face.  Thanks in advance,

 Here’s a screen-shot of how org-hide, which sets foreground to white, leaks.

Oh, and here’s the output of C-u C-x =, which might help:

 position: 25567 of 32560 (79%), column: 0
character: * (displayed as ** TODO Show Bastien erroneous
=org-hide= face application   | ) (codepoint 42,
#o52, #x2a)
preferred charset: ascii (ASCII (ISO646 IRV))
code point in charset: 0x2A
   syntax: _which means: symbol
 category: .:Base, a:ASCII, l:Latin, r:Roman
 to input: type C-x 8 RET HEX-CODEPOINT or C-x 8 RET NAME
  buffer code: #x2A
file code: #x2A (encoded by coding system utf-8-unix)
  display: terminal code #x2A

Character code properties: customize what to show
  name: ASTERISK
  general-category: Po (Punctuation, Other)
  decomposition: (42) ('*')

There is an overlay here:
 From 25567 to 25568
  display  [Show]
  face ((:foreground unspecified) (:height 1 :family
default) org-column org-level-2)
  keymap   [Show]
  line-prefix  
  org-columns-format   %-80.80s | 
  org-columns-key  ITEM
  org-columns-pom  nil
  org-columns-value** TODO Show Bastien erroneous =org-hide= face
application
  org-columns-value-modified [Show]
  wrap-prefix  


There are text properties here:
  face org-hide
  fontifiedt
  line-prefix  [Show]
  org-category [Show]
  org-category-position 1
  org-summaries((Effort . ))
  read-onlyType `e' to edit property
  wrap-prefix  [Show]

[back]



Re: [O] How to use ispell in org mode: goal is to skip source blocks

2014-05-21 Thread Nicolas Goaziou
Hello,

Bastien b...@gnu.org writes:

 Igor Sosa Mayor joseleopoldo1...@gmail.com writes:

 Bastien b...@gnu.org writes:

 [...]

 You can use this:

 (add-to-list 'ispell-skip-region-alist '(#\\+begin_src. #\\+end_src))

 wow, interesting... I was not aware of this feature. Thanks a lot!

 Not really a FAQ, but useful, so I've added a note here:
 http://orgmode.org/worg/org-faq.html#sec-22-4

Note that it shouldn't be necessary in Org 8.3.


Regards,

-- 
Nicolas Goaziou



Re: [O] How to use ispell in org mode: goal is to skip source blocks

2014-05-21 Thread Bastien
Nicolas Goaziou n.goaz...@gmail.com writes:

 Not really a FAQ, but useful, so I've added a note here:
 http://orgmode.org/worg/org-faq.html#sec-22-4

 Note that it shouldn't be necessary in Org 8.3.

From what I understand, it isn't necessary if the user is using
flyspell.  But when using M-x ispell-buffer RET directly, source
blocks are still checked.  Or did I miss something?

-- 
 Bastien



Re: [O] Integration of Groupware calendar solutions like CalendarTree

2014-05-21 Thread Karl Voit
* Bastien b...@gnu.org wrote:
 Hi Karl,

Hi Bastien!

 Karl Voit devn...@karl-voit.at writes:

 I wondered how easy somebody could implement support for Org-mode?

 Maybe you can ping the calendartree.com for this?

 They get paid for their work and would certainly love to get a larger
 customer base by adding such a cool feature.  And they have a better
 knowledge of how their system works.

Yes, I agree.

However, I am afraid, that this is a one-man-show only (the guy
drawing Dilbert!) and he most probably wants to concentrate on
interfaces with a high effort-to-users-ratio. And this is where
Org-mode is almost non-existent: a moderate to high effort to
integrate smoothly with a *very* limited number of users/customers.
:-(

My question was not only targeted to CalendarTree in particular.
More of a general question to get the opinion of others, how they
see the need/possibilities for Groupware-features enabled by
non-Emacs-based services. Probably, it's just me who wants to
send/receive appointments to peers that aren't using Emacs.

I used CalendarTree only as an example because it is a service which
tries to combine/connect different worlds together which is an
unusual goal these days (most people want to lock you in their
service instead of connecting you). 

If the Org-mode community wants to connect to such services, the
org-mode community has to initiate it and implement it on its own -
I am afraid. Just because - compared to the rest of the IT-world -
nobody uses Org-mode.

-- 
mail|git|SVN|photos|postings|SMS|phonecalls|RSS|CSV|XML to Org-mode:
get Memacs from https://github.com/novoid/Memacs 

https://github.com/novoid/extract_pdf_annotations_to_orgmode + more on github




Re: [O] How to use ispell in org mode: goal is to skip source blocks

2014-05-21 Thread Nicolas Goaziou
Bastien b...@gnu.org writes:

 From what I understand, it isn't necessary if the user is using
 flyspell.  But when using M-x ispell-buffer RET directly, source
 blocks are still checked.  Or did I miss something?

No, you're right. I thought about M-x flyspell-buffer after
flyspell-mode has been enabled.


Regards,

-- 
Nicolas Goaziou



Re: [O] wish: provide flush_right/right_aligned text rendering directive

2014-05-21 Thread Nicolas Goaziou
Bastien b...@gnu.org writes:

 Maybe

 begin_justifyright
 begin_justifyleft
 begin_justifyfull

 to reuse the Emacs terminology for text alignment?

I find it a bit verbose, but probably clearer than begin_right and
begin_left.

OTOH, I'd rather not implement justifyfull as it is not necessary at
the time being and requires more work.


Regards,

-- 
Nicolas Goaziou



Re: [O] org-table-copy-down incrementor

2014-05-21 Thread Michael Brand
Hi Bastien

On Tue, May 20, 2014 at 9:45 PM, Bastien b...@gnu.org wrote:
 Yes.  There is also `thing-at-point' which does not recognize 1.1 as a
 number... I circumvented this by using `calc-eval'.  The above should
 now work correctly.

Yes it does. Using Calc is a nice solution, thank you.

I did not notice before but the first commit
7ac468ff5547891503b6b8f5fa03793d79b3bff6
changed SHIFT-RET on the empty field
| 2 |
| 5 |
|   |
to add a new row instead of only replacing the current field.

Michael



Re: [O] Clock-in in agenda makes some headings with links disappear

2014-05-21 Thread Bastien
Hi Thomas,

Thomas Morgan t...@ziiuu.com writes:

 Here is a recipe for what might be another manifestation
 of this bug.

Thanks for this new report -- can you apply this patch against maint
and see if it works correctly?  Not only for the bug at stake, but all
kind of agenda filtering, rescheduling, clocking, etc.

The tests are pretty weak for the agenda (my bad), and this is quite
a significant rewrite, using text properties instead of overlays for
agenda filtering.

Thanks in advance!

diff --git a/lisp/org-agenda.el b/lisp/org-agenda.el
index fe32202..c1a2e1b 100644
--- a/lisp/org-agenda.el
+++ b/lisp/org-agenda.el
@@ -2092,11 +2092,8 @@ When nil, `q' will kill the single agenda buffer.
 org-agenda-info
 org-agenda-pre-window-conf
 org-agenda-columns-active
-org-agenda-tag-filter-overlays
 org-agenda-tag-filter
-org-agenda-cat-filter-overlays
 org-agenda-category-filter
-org-agenda-re-filter-overlays
 org-agenda-regexp-filter
 org-agenda-markers
 org-agenda-last-search-view-search-was-boolean
@@ -3324,19 +3321,12 @@ If AGENDA-BUFFER-NAME, use this as the buffer name for the agenda to write.
   (org-let (if nosettings nil org-agenda-exporter-settings)
 '(save-excursion
(save-window-excursion
-	 (org-agenda-mark-filtered-text)
 	 (let ((bs (copy-sequence (buffer-string))) beg content)
-	   (org-agenda-unmark-filtered-text)
 	   (with-temp-buffer
 	 (rename-buffer org-agenda-write-buffer-name t)
 	 (set-buffer-modified-p nil)
 	 (insert bs)
 	 (org-agenda-remove-marked-text 'org-filtered)
-	 (while (setq beg (text-property-any (point-min) (point-max)
-		 'org-filtered t))
-	   (delete-region
-		beg (or (next-single-property-change beg 'org-filtered)
-			(point-max
 	 (run-hooks 'org-agenda-before-write-hook)
 	 (cond
 	  ((org-bound-and-true-p org-mobile-creating-agendas)
@@ -3402,28 +3392,6 @@ If AGENDA-BUFFER-NAME, use this as the buffer name for the agenda to write.
 		org-agenda-buffer-name)))
   (when open (org-open-file file)))
 
-(defvar org-agenda-tag-filter-overlays nil)
-(defvar org-agenda-cat-filter-overlays nil)
-(defvar org-agenda-re-filter-overlays nil)
-
-(defun org-agenda-mark-filtered-text ()
-  Mark all text hidden by filtering with a text property.
-  (let ((inhibit-read-only t))
-(mapc
- (lambda (o)
-   (when (equal (overlay-buffer o) (current-buffer))
-	 (put-text-property
-	  (overlay-start o) (overlay-end o)
-	  'org-filtered t)))
- (append org-agenda-tag-filter-overlays
-	 org-agenda-cat-filter-overlays
-	 org-agenda-re-filter-overlays
-
-(defun org-agenda-unmark-filtered-text ()
-  Remove the filtering text property.
-  (let ((inhibit-read-only t))
-(remove-text-properties (point-min) (point-max) '(org-filtered t
-
 (defun org-agenda-remove-marked-text (property optional value)
   Delete all text marked with VALUE of PROPERTY.
 VALUE defaults to t.
@@ -3432,7 +3400,7 @@ VALUE defaults to t.
 (while (setq beg (text-property-any (point-min) (point-max)
 	property value))
   (delete-region
-   beg (or (next-single-property-change beg 'org-filtered)
+   beg (or (next-single-property-change beg property)
 	   (point-max))
 
 (defun org-agenda-add-entry-text ()
@@ -7400,7 +7368,8 @@ With two prefix arguments, remove the regexp filters.
   (when org-agenda-category-filter
 (org-agenda-filter-show-all-cat))
   (when org-agenda-regexp-filter
-(org-agenda-filter-show-all-re)))
+(org-agenda-filter-show-all-re))
+  (org-agenda-finalize))
 
 (defun org-agenda-filter-by-tag (strip optional char narrow)
   Keep only those lines in the agenda buffer that have a specific tag.
@@ -7672,50 +7641,31 @@ When NO-OPERATOR is non-nil, do not add the + operator to returned tags.
 (defun org-agenda-filter-hide-line (type)
   Hide lines with TYPE in the agenda buffer.
   (let* ((b (max (point-min) (1- (point-at-bol
-	 (e (point-at-eol))
-	 (ov (make-overlay b e)))
-(overlay-put ov 'invisible t)
-(overlay-put ov 'intangible t)
-(overlay-put ov 'type type)
-(cond ((eq type 'tag) (push ov org-agenda-tag-filter-overlays))
-	  ((eq type 'category) (push ov org-agenda-cat-filter-overlays))
-	  ((eq type 'regexp) (push ov org-agenda-re-filter-overlays)
-
-(defun org-agenda-fix-tags-filter-overlays-at (optional pos)
-  (setq pos (or pos (point)))
-  (save-excursion
-(dolist (ov (overlays-at pos))
-  (when (and (overlay-get ov 'invisible)
-		 (eq (overlay-get ov 'type) 'tag))
-	(goto-char pos)
-	(if ( (overlay-start ov) (point-at-eol))
-	(move-overlay ov (point-at-eol)
-			  (overlay-end ov)))
+	 (e (point-at-eol)))
+(let ((inhibit-read-only t))
+  (add-text-properties
+   b e `(invisible t org-filtered t org-filter-type ,type)
 
-(defun org-agenda-filter-show-all-tag nil
-  Remove tag filter overlays from the agenda buffer.
-  (mapc 'delete-overlay org-agenda-tag-filter-overlays)

Re: [O] org-table-copy-down incrementor

2014-05-21 Thread Bastien
Hi Michael,

Michael Brand michael.ch.br...@gmail.com writes:

 I did not notice before but the first commit
 7ac468ff5547891503b6b8f5fa03793d79b3bff6
 changed SHIFT-RET on the empty field
 | 2 |
 | 5 |
 |   |
 to add a new row instead of only replacing the current field.

This is now fixed in master, thanks for spotting this.

-- 
 Bastien



Re: [O] wish: provide flush_right/right_aligned text rendering directive

2014-05-21 Thread Bastien
Nicolas Goaziou n.goaz...@gmail.com writes:

 I find it a bit verbose, but probably clearer than begin_right and
 begin_left.

My impression too...

 OTOH, I'd rather not implement justifyfull as it is not necessary at
 the time being and requires more work.

Can't this be done with `default-justification' set to 'full?

Anyway, I agree full justification is *bad*.

-- 
 Bastien



Re: [O] wish: provide flush_right/right_aligned text rendering directive

2014-05-21 Thread Nicolas Goaziou
Bastien b...@gnu.org writes:

 Can't this be done with `default-justification' set to 'full?

Alas, only in the simple cases. The block may contain elements that
needs to be treated differently, e.g., tables.


Regards,

-- 
Nicolas Goaziou



Re: [O] latex export beginner

2014-05-21 Thread Steven Arntson
Nick Dokos ndo...@gmail.com writes:

 Steven Arntson ste...@stevenarntson.com writes:

 I'm taking my first baby steps at exporting an org file to LaTex. I know
 a little about org-mode, and almost nothing about LaTex.

 I type C-c C-e l o

 A file named file.tex is produced, but the process halts with an error:

 org-latex-compile: PDF file ./plm.pdf wasn't produced: [LaTeX error] 

 A program called pdfTex produces a buffer with extensive output,
 including:

 ! LaTeX Error: Missing \begin{document}.

 This seems like some markup that should probably be included in my file
 automatically as part of the export? Shoud I add /begin{document} to
 my org doc?


 No, the exporter should have done that. Post your org file and the
 resulting tex file.

 Also, the version of your org mode: C-u M-x org-version will insert
 it in the current buffer.

Thank you for your help!

I'm using Org-mode version 8.2.6 (8.2.6-22-gb11b4a-elpaplus @
/home/steven/.emacs.d/elpa/org-plus-contrib-20140519/)

I mocked up a smaller reproduction of the problem, because the original
file is too large. The same errors were produced. There's a file called
test.log, too, which I'm not pasting in here because of its length, but
I can if it would be helpful. Here's my org-mode document:

| Test org file for conversion to LaTex
|  
| * My top-level header
| Some information under the top level header
| ** A secondary header
|  
| * Chapter the first
| Some information from the first chapter.Some
| information from the first Some information from the first chapter.Some
| information from the first chapter.Some information from the first
| chapter.
|  
| * Chapter the second
| The end of this document.

And here is the tex output file:

| % Created 2014-05-21 Wed 09:11
| \documentclass[11pt]{article}
| \usepackage[utf8]{inputenc}
| \usepackage[T1]{fontenc}
| \usepackage{fixltx2e}
| \usepackage{graphicx}
| \usepackage{longtable}
| \usepackage{float}
| \usepackage{wrapfig}
| \usepackage{rotating}
| \usepackage[normalem]{ulem}
| \usepackage{amsmath}
| \usepackage{textcomp}
| \usepackage{marvosym}
| \usepackage{wasysym}
| \usepackage{amssymb}
| \usepackage{hyperref}
| \tolerance=1000
| \author{Steven Arntson}
| \date{\today}
| \title{test}
| \hypersetup{
|   pdfkeywords={},
|   pdfsubject={},
|   pdfcreator={Emacs 24.3.1 (Org mode 8.2.6)}}
| \begin{document}
|  
| \maketitle
| \tableofcontents
|  
| Test org file for conversion to LaTex
|  
| \section{My top-level header}
| \label{sec-1}
| Some information under the top level header
| \subsection{A secondary header}
| \label{sec-1-1}
|  
| \section{Chapter the first} \label{sec-2}
| Some information from the
| first chapter.Some information from the first Some information from the
| first chapter.Some information from the first chapter.Some information
| from the first chapter.
|  
| \section{Chapter the second}
| \label{sec-3}
| The end of this document.
| % Emacs 24.3.1 (Org mode 8.2.6)
| \end{document}





Re: [O] wish: provide flush_right/right_aligned text rendering directive

2014-05-21 Thread Bastien
Nicolas Goaziou n.goaz...@gmail.com writes:

 Bastien b...@gnu.org writes:

 Can't this be done with `default-justification' set to 'full?

 Alas, only in the simple cases. The block may contain elements that
 needs to be treated differently, e.g., tables.

Yes -- I suggest we simply put this aside for the moment.

-- 
 Bastien



Re: [O] latex export beginner

2014-05-21 Thread Igor Sosa Mayor
Steven Arntson ste...@stevenarntson.com writes:

 Thank you for your help!

 I'm using Org-mode version 8.2.6 (8.2.6-22-gb11b4a-elpaplus @
 /home/steven/.emacs.d/elpa/org-plus-contrib-20140519/)

 I mocked up a smaller reproduction of the problem, because the original
 file is too large. The same errors were produced. There's a file called
 test.log, too, which I'm not pasting in here because of its length, but
 I can if it would be helpful. Here's my org-mode document:

I think we need the whole output buffer of the pdf compilation by
pdflatex. I have the impression in your system you lack some of the used
latex packages. 


-- 
:: Igor Sosa Mayor :: joseleopoldo1...@gmail.com ::
:: GnuPG: 0x1C1E2890   :: http://www.gnupg.org/  ::
:: jabberid: rogorido  ::::




Re: [O] org-table-copy-down incrementor

2014-05-21 Thread Michael Brand
Hi Bastien

On Wed, May 21, 2014 at 5:49 PM, Bastien b...@gnu.org wrote:
 Michael Brand michael.ch.br...@gmail.com writes:
 I did not notice before but the first commit
 7ac468ff5547891503b6b8f5fa03793d79b3bff6
 changed SHIFT-RET on the empty field
 | 2 |
 | 5 |
 |   |
 to add a new row instead of only replacing the current field.

 This is now fixed in master, thanks for spotting this.

I get a setq: Wrong type argument: stringp with SHIFT-RET in the empty
field of
| 2 |
|   |
and
| [2014-04-30 Wed] |
|  |
and
| 1.1 |
| |

Michael



Re: [O] Moving footnotes

2014-05-21 Thread Nicolas Goaziou
Hello,

Leonard Randall leonard.a.rand...@gmail.com writes:

 Additionally, if I try to export a subtree as an org buffer, it does
 not take footnote definitions with it.

This particular point should now be fixed. Thank you for reporting it.


Regards,

-- 
Nicolas Goaziou



Re: [O] org-table-copy-down incrementor

2014-05-21 Thread Bastien
Michael Brand michael.ch.br...@gmail.com writes:

 I get a setq: Wrong type argument: stringp with SHIFT-RET in the empty
 field of
 | 2 |
 |   |
 and
 | [2014-04-30 Wed] |
 |  |
 and
 | 1.1 |
 | |

Er, fixed, thanks!

-- 
 Bastien



Re: [O] org-table-copy-down incrementor

2014-05-21 Thread Michael Brand
Hi Bastien

On Wed, May 21, 2014 at 6:38 PM, Bastien b...@gnu.org wrote:
 Er, fixed, thanks!

I tried some (3 * 2 * 2) variants and all work, thank you.

Michael



Re: [O] latex export beginner

2014-05-21 Thread Nick Dokos
Steven Arntson ste...@stevenarntson.com writes:

 Nick Dokos ndo...@gmail.com writes:

 Steven Arntson ste...@stevenarntson.com writes:

 I'm taking my first baby steps at exporting an org file to LaTex. I know
 a little about org-mode, and almost nothing about LaTex.

 I type C-c C-e l o

 A file named file.tex is produced, but the process halts with an error:

 org-latex-compile: PDF file ./plm.pdf wasn't produced: [LaTeX error] 

 A program called pdfTex produces a buffer with extensive output,
 including:

 ! LaTeX Error: Missing \begin{document}.

 This seems like some markup that should probably be included in my file
 automatically as part of the export? Shoud I add /begin{document} to
 my org doc?


 No, the exporter should have done that. Post your org file and the
 resulting tex file.

 Also, the version of your org mode: C-u M-x org-version will insert
 it in the current buffer.

 Thank you for your help!

 I'm using Org-mode version 8.2.6 (8.2.6-22-gb11b4a-elpaplus @
 /home/steven/.emacs.d/elpa/org-plus-contrib-20140519/)

 I mocked up a smaller reproduction of the problem, because the original
 file is too large. The same errors were produced. There's a file called
 test.log, too, which I'm not pasting in here because of its length, but
 I can if it would be helpful.

Yes, please: as Igor Sosa Mayor mentioned, you are probably missing some
latex packages. The document exports and compiles without any problems
here. If you are on Linux and use the TeXlive distribution of TeX, then
you can check for the existence of e.g. package ulem with

kpsewhich ulem.sty

Not sure about other systems.

 Here's my org-mode document:

 | Test org file for conversion to LaTex
 |  
 | * My top-level header
 | Some information under the top level header
 | ** A secondary header
 |  
 | * Chapter the first
 | Some information from the first chapter.Some
 | information from the first Some information from the first chapter.Some
 | information from the first chapter.Some information from the first
 | chapter.
 |  
 | * Chapter the second
 | The end of this document.

 And here is the tex output file:

 | % Created 2014-05-21 Wed 09:11
 | \documentclass[11pt]{article}
 | \usepackage[utf8]{inputenc}
 | \usepackage[T1]{fontenc}
 | \usepackage{fixltx2e}
 | \usepackage{graphicx}
 | \usepackage{longtable}
 | \usepackage{float}
 | \usepackage{wrapfig}
 | \usepackage{rotating}
 | \usepackage[normalem]{ulem}
 | \usepackage{amsmath}
 | \usepackage{textcomp}
 | \usepackage{marvosym}
 | \usepackage{wasysym}
 | \usepackage{amssymb}
 | \usepackage{hyperref}
 | \tolerance=1000
 | \author{Steven Arntson}
 | \date{\today}
 | \title{test}
 | \hypersetup{
 |   pdfkeywords={},
 |   pdfsubject={},
 |   pdfcreator={Emacs 24.3.1 (Org mode 8.2.6)}}
 | \begin{document}
 |  
 | \maketitle
 | \tableofcontents
 |  
 | Test org file for conversion to LaTex
 |  
 | \section{My top-level header}
 | \label{sec-1}
 | Some information under the top level header
 | \subsection{A secondary header}
 | \label{sec-1-1}
 |  
 | \section{Chapter the first} \label{sec-2}
 | Some information from the
 | first chapter.Some information from the first Some information from the
 | first chapter.Some information from the first chapter.Some information
 | from the first chapter.
 |  
 | \section{Chapter the second}
 | \label{sec-3}
 | The end of this document.
 | % Emacs 24.3.1 (Org mode 8.2.6)
 | \end{document}

I'd suggest that you use this style of quote:


--8---cut here---start-8---
Quoted text
--8---cut here---end---8---

for stuff that your correspondents might want to use: easier to
just cut-and-paste. This is done with the command

 M-x message-mark-inserted-region

(which is bound to C-c M-m by default I think).


Nick




Re: [O] [bug] Commented DEADLINE line still referenced

2014-05-21 Thread Sebastien Vauban


Hi Bastien,

Bastien wrote:
 Sebastien Vauban writes:

 Having such lines in one Org file (where the DEADLINE line is
 commented):

 ** TODO Aspirer les filtres de ventilation D350
# DEADLINE: 2014-04-09 Wed .+1m -0d

 still makes that task be referenced in my agenda.

 Which agenda?

This custom view:

#+begin_src emacs-lisp
(add-to-list 'org-agenda-custom-commands
 '(f Today

   ;; list of all TODO entries with deadline today
   ((tags-todo DEADLINE=\+0d\
   ((org-agenda-overriding-header DUE TODAY)
(org-agenda-skip-function
 '(org-agenda-skip-entry-if 'notdeadline))
(org-agenda-sorting-strategy '(priority-down

;; list of all TODO entries with deadline before today
(tags-todo DEADLINE\+0d\
   ((org-agenda-overriding-header OVERDUE)
(org-agenda-skip-function
 '(org-agenda-skip-entry-if 'notdeadline))
(org-agenda-sorting-strategy 
'(priority-down)) t)
#+end_src

 I cannot reproduce this with a simple week agenda view.

Here is an ECM file:

--8---cut here---start-8---
#+TITLE: Example of Tasks
#+LANGUAGE:  en

* Marketing
  :PROPERTIES:
  :CATEGORY: Marketing
  :END:

** TODO Check payment of rent
   # DEADLINE: 2014-05-15 Thu ++1m -0d
   :PROPERTIES:
   :LAST_REPEAT: [2014-05-02 Fri 17:45]
   :Effort:   0:10
   :END:
--8---cut here---end---8---

See how it behaves on http://screencast.com/t/Yoj5uSA8Wb: I really need
to break the DEADLINE keyword for it to become inactive. Putting it in
a comment is not enough.

Best regards,
  Seb

-- 
Sebastien Vauban




Re: [O] (Bug)Open the attachment in the subheading in agenda view

2014-05-21 Thread Bastien
Hi Kyutech,

Kyutech lei-...@edu.life.kyutech.ac.jp writes:

 I have turned on the inheritance of the properties,

Do you have a :ATTACH_DIR_INHERIT: t in the top heading you want the
attachments to be inherited from?

HTH,

-- 
 Bastien



[O] Pandoc users, how do you use it with org-mode, and why?

2014-05-21 Thread Grant Rettke
Hi,

Lately been hearing great things about Pandoc's ability to export to ebook
formats and more.

Folks that use both Pandoc and org-mode: how do you use them together, and
why?

Kind regards,

Grant Rettke | AAAS, ACM, ASA, FSF, IEEE, SIAM, Sigma Xi
g...@wisdomandwonder.com | http://www.wisdomandwonder.com/
“Wisdom begins in wonder.” --Socrates
((λ (x) (x x)) (λ (x) (x x)))
“Life has become immeasurably better since I have been forced to stop
taking it seriously.” --Thompson


Re: [O] Insert #+BEAMER_HEADER_EXTRA before \begin{document}?

2014-05-21 Thread Sebastien Vauban
Hi Eric, Suvayu and al.

Eric S Fraga wrote:
 On Thursday,  8 May 2014 at 15:38, Sebastien Vauban wrote:
 The above things are currently (almost, for some) impossible.  Changing
 where the #+BEAMER_HEADER placeholder gets inserted makes them possible
 and easy.

 but unfortunately would make other things more difficult.  For instance,
 I often redefine the date command (and sometimes title and author) to do
 something different.  If the header entries were placed after the use of
 theses, things would break for me.

 I think the creation of an ...EXTRA directive would be better but I've
 argued for this before and have lost that argument.

I also think that having 2 locations is better than just 1, as I'm also
sure one will work better or only for specific things, but will break
for others.

Having 2 placeholders allow for full customization, if correctly
placed -- at least, one just before the begin{document}, the other?

 You can achieve what you want by redefining \title, I would
 suggest.  Not pretty but it works.

For sure, such a thing is not pretty:

--8---cut here---start-8---
#+BIND: org-latex-title-command \\title[Short title]{Title which can 
bevery long}\n\\author[F. Last]{\\href{mailto:first.l...@isp.com}{First 
Last}}\n\\date[May 2014]{21 May 2014}\n\\maketitle
--8---cut here---end---8---

But the whole point is that is DOES NOT even WORK for a couple of
things, such as modifying base colors of a theme:

--8---cut here---start-8---
#+BEAMER_HEADER: \setbeamercolor{frametitle}{bg=blue}
--8---cut here---end---8---

won't work because of the misplacement of the BEAMER_HEADER placeholder
regarding to the (color) theme: the above line will be placed before the
choice of the theme... TOO EARLY.

On the contrary, adding it in the above title command (already in the
LaTeX document, that is) is TOO LATE.

Best regards,
  Seb

-- 
Sebastien Vauban



Re: [O] Integration of Groupware calendar solutions like CalendarTree

2014-05-21 Thread Eric S Fraga
Hi Karl.

What about org-caldav [1]?  Not quite what you want but if you sync with
a calendar that can be shared, it does in effect achieve your goal.  I
do this with google's calendar which I can indeed share with others.

Mind you, syncing with google calendar is deprecated due to
authentication issues, but that's another story.

eric

Footnotes: 
[1]  https://github.com/dengste/org-caldav

-- 
: Eric S Fraga (0xFFFCF67D), Emacs 24.4.50.2, Org release_8.2.6-966-g6cdf1b



Re: [O] Pandoc users, how do you use it with org-mode, and why?

2014-05-21 Thread Eric S Fraga
On Wednesday, 21 May 2014 at 13:01, Grant Rettke wrote:
 Hi,

 Lately been hearing great things about Pandoc's ability to export to ebook
 formats and more.

 Folks that use both Pandoc and org-mode: how do you use them together, and
 why?

I've only recently started using pandoc and I have exactly one use case:
the need, in some cases, to produce a .docx document with
mathematics.  Pandoc will convert LaTeX to docx and handles equations
reasonably well (not perfect but better than any other alternative I
have found to date).  The LaTeX generated by org is usually perfectly
fine.

For 98% of my needs, org + included exporters + babel is more than
enough, mind you.

-- 
: Eric S Fraga (0xFFFCF67D), Emacs 24.4.50.2, Org release_8.2.6-966-g6cdf1b



Re: [O] Pandoc users, how do you use it with org-mode, and why?

2014-05-21 Thread Vikas Rawal

 
 Lately been hearing great things about Pandoc's ability to export to ebook
 formats and more.
 
 Folks that use both Pandoc and org-mode: how do you use them together, and
 why?
 
 I've only recently started using pandoc and I have exactly one use case:
 the need, in some cases, to produce a .docx document with
 mathematics.  Pandoc will convert LaTeX to docx and handles equations
 reasonably well (not perfect but better than any other alternative I
 have found to date).  The LaTeX generated by org is usually perfectly
 fine.
 

Pandoc to docx/odt conversion handles bibtex/biblatex citations, which built-in 
org to odt/docx conversion does not.
 
Vikas


Re: [O] Pandoc users, how do you use it with org-mode, and why?

2014-05-21 Thread Igor Sosa Mayor
Vikas Rawal vikasli...@agrarianresearch.org writes:

 Pandoc to docx/odt conversion handles bibtex/biblatex citations, which
 built-in org to odt/docx conversion does not.

+1

it works reasonably well for latex-(odt)-doc, even with biblatex. 




Re: [O] Preserve formatting when copy/pasting from HTML

2014-05-21 Thread Ilya Shlyakhter
torys.ander...@gmail.com (Tory S. Anderson) writes:

 We often read online articles with headings and sometimes
 subheadings. They may also include bold, italic, and hyperlinks, all
 of which are supported by Org. Is there any way to preserve this
 formatting if I copy-paste into org/emacs, the same way it's preserved
 when I paste into Word or into a Google Document/email? Or is this
 fundamentally difficult in emacs? It would be a tremendous feature.

There is an extension for doing this when copying from emacs-w3m into
org: http://orgmode.org/w/?p=org-mode.git;a=blob_plain;f=lisp/org-w3m.el;hb=HEAD




Re: [O] [PATCH] Make the point visible when jumping to the mark

2014-05-21 Thread Ian Kelling
Bastien b...@gnu.org writes:
 The formatting of the Changelog message not good.

 It should be

 * org.el: Advise commands which jump to the mark.

 See http://orgmode.org/worg/org-contribute.html and example in
 the git logs.


My mistake. Fixed in the attached patch.

 +(eval-after-load simple
 +  '(defadvice set-mark-command (after org-make-visible activate)
 + Make the point visible with `org-show-context'.
 + (org-mark-jump-unhide)))

 Why this one?  The user don't want to use C-SPC in hidden parts.

Yes, I agree. They want to use C-u C-SPC to go to hidden parts. I've
updated the patch to advise pop-to-mark-command instead. It is attached.

From ead59ed465eb33e822dd69f6e34b087477ebc239 Mon Sep 17 00:00:00 2001
From: Ian Kelling i...@iankelling.org
Date: Wed, 30 Apr 2014 21:54:08 -0700
Subject: [PATCH] Make the point visible when jumping to the mark

* org.el: Advise commands which jump to the mark
---
 lisp/org.el |   21 +
 1 file changed, 21 insertions(+)

diff --git a/lisp/org.el b/lisp/org.el
index 40e16ea..17f7997 100644
--- a/lisp/org.el
+++ b/lisp/org.el
@@ -24510,6 +24510,27 @@ To get rid of the restriction, use \\[org-agenda-remove-restriction-lock].
 			   (outline-invisible-p)))
(org-show-context 'bookmark-jump)))
 
+(eval-after-load simple
+  '(defadvice pop-to-mark-command (after org-make-visible activate)
+ Make the point visible with `org-show-context'.
+ (org-mark-jump-unhide)))
+
+(eval-after-load simple
+  '(defadvice exchange-point-and-mark (after org-make-visible activate)
+ Make the point visible with `org-show-context'.
+ (org-mark-jump-unhide)))
+
+(eval-after-load simple
+  '(defadvice pop-global-mark (after org-make-visible activate)
+ Make the point visible with `org-show-context'.
+ (org-mark-jump-unhide)))
+
+(defun org-mark-jump-unhide ()
+  Make the point visible with `org-show-context' after jumping to the mark.
+  (when (and (derived-mode-p 'org-mode)
+	 (outline-invisible-p))
+(org-show-context 'mark-goto)))
+
 ;; Make session.el ignore our circular variable
 (defvar session-globals-exclude)
 (eval-after-load session
-- 
1.7.10.4



Re: [O] latex export beginner

2014-05-21 Thread Steven Arntson
Nick Dokos ndo...@gmail.com writes:

 Steven Arntson ste...@stevenarntson.com writes:

 Nick Dokos ndo...@gmail.com writes:

 Steven Arntson ste...@stevenarntson.com writes:

 I'm taking my first baby steps at exporting an org file to
 LaTex. I know
 a little about org-mode, and almost nothing about LaTex.

 I type C-c C-e l o

 A file named file.tex is produced, but the process halts with an
 error:

 org-latex-compile: PDF file ./plm.pdf wasn't produced: [LaTeX error] 

 A program called pdfTex produces a buffer with extensive output,
 including:

 ! LaTeX Error: Missing \begin{document}.

 This seems like some markup that should probably be included in my
 file
 automatically as part of the export? Shoud I add /begin{document} to
 my org doc?


 No, the exporter should have done that. Post your org file and the
 resulting tex file.

 Also, the version of your org mode: C-u M-x org-version will insert
 it in the current buffer.

 Thank you for your help!

 I'm using Org-mode version 8.2.6 (8.2.6-22-gb11b4a-elpaplus @
 /home/steven/.emacs.d/elpa/org-plus-contrib-20140519/)

 I mocked up a smaller reproduction of the problem, because the original
 file is too large. The same errors were produced. There's a file called
 test.log, too, which I'm not pasting in here because of its length, but
 I can if it would be helpful.

 Yes, please: as Igor Sosa Mayor mentioned, you are probably missing some
 latex packages. The document exports and compiles without any problems
 here. If you are on Linux and use the TeXlive distribution of TeX, then
 you can check for the existence of e.g. package ulem with

 kpsewhich ulem.sty

 Not sure about other systems.

 Here's my org-mode document:

 | Test org file for conversion to LaTex
 |  
 | * My top-level header
 | Some information under the top level header
 | ** A secondary header
 |  
 | * Chapter the first
 | Some information from the first chapter.Some
 | information from the first Some information from the first
 | chapter.Some
 | information from the first chapter.Some information from the first
 | chapter.
 |  
 | * Chapter the second
 | The end of this document.

 And here is the tex output file:

 | % Created 2014-05-21 Wed 09:11
 | \documentclass[11pt]{article}
 | \usepackage[utf8]{inputenc}
 | \usepackage[T1]{fontenc}
 | \usepackage{fixltx2e}
 | \usepackage{graphicx}
 | \usepackage{longtable}
 | \usepackage{float}
 | \usepackage{wrapfig}
 | \usepackage{rotating}
 | \usepackage[normalem]{ulem}
 | \usepackage{amsmath}
 | \usepackage{textcomp}
 | \usepackage{marvosym}
 | \usepackage{wasysym}
 | \usepackage{amssymb}
 | \usepackage{hyperref}
 | \tolerance=1000
 | \author{Steven Arntson}
 | \date{\today}
 | \title{test}
 | \hypersetup{
 |   pdfkeywords={},
 |   pdfsubject={},
 |   pdfcreator={Emacs 24.3.1 (Org mode 8.2.6)}}
 | \begin{document}
 |  
 | \maketitle
 | \tableofcontents
 |  
 | Test org file for conversion to LaTex
 |  
 | \section{My top-level header}
 | \label{sec-1}
 | Some information under the top level header
 | \subsection{A secondary header}
 | \label{sec-1-1}
 |  
 | \section{Chapter the first} \label{sec-2}
 | Some information from the
 | first chapter.Some information from the first Some information
 | from the
 | first chapter.Some information from the first chapter.Some information
 | from the first chapter.
 |  
 | \section{Chapter the second}
 | \label{sec-3}
 | The end of this document.
 | % Emacs 24.3.1 (Org mode 8.2.6)
 | \end{document}

 I'd suggest that you use this style of quote:


 Quoted text

 for stuff that your correspondents might want to use: easier to
 just cut-and-paste. This is done with the command

  M-x message-mark-inserted-region

 (which is bound to C-c M-m by default I think).


 Nick

Hi Nick,

Just in case there was something haywire, I uninstalled and reinstalled
TexLive. I'm still getting the same error. Below is the content of the
.log file. Glancing through with an unpracticed eye, I see a line that
says file wrapfig.sty not found. Thanks again for helping me troubleshoot!

This is pdfTeX, Version 3.1415926-2.5-1.40.14 (TeX Live 2013/Debian) 
(format=pdflatex 2014.4.25)  21 MAY 2014 12:32
entering extended mode
 restricted \write18 enabled.
 %-line parsing enabled.
**/home/steven/Desktop/test.tex
(/home/steven/Desktop/test.tex
LaTeX2e 2011/06/27
Babel 3.9f and hyphenation patterns for 2 languages loaded.
(/usr/share/texlive/texmf-dist/tex/latex/base/article.cls
Document Class: article 2007/10/19 v1.4h Standard LaTeX document class
(/usr/share/texlive/texmf-dist/tex/latex/base/size11.clo
File: size11.clo 2007/10/19 v1.4h Standard LaTeX file (size option)
)
\c@part=\count79
\c@section=\count80
\c@subsection=\count81
\c@subsubsection=\count82
\c@paragraph=\count83
\c@subparagraph=\count84
\c@figure=\count85
\c@table=\count86
\abovecaptionskip=\skip41
\belowcaptionskip=\skip42
\bibindent=\dimen102
)
(/usr/share/texlive/texmf-dist/tex/latex/base/inputenc.sty
Package: inputenc 2008/03/30 v1.1d Input 

Re: [O] latex export beginner

2014-05-21 Thread Igor Sosa Mayor
Steven Arntson ste...@stevenarntson.com writes:

 Nick Dokos ndo...@gmail.com writes:


well, it's pretty clear...

! LaTeX Error: File `wrapfig.sty' not found.

you have to install the wrapfig package. If you're in debian/ubuntu:

sudo apt-get install texlive-latex-extra


-- 
:: Igor Sosa Mayor :: joseleopoldo1...@gmail.com ::
:: GnuPG: 0x1C1E2890   :: http://www.gnupg.org/  ::
:: jabberid: rogorido  ::::




[O] Desktop search for Org-Mode (linux/os-x). Looking for betas and code reviewers

2014-05-21 Thread Jonathan Coupe

Hi-

I'm working on an interface between the excellent recoll desktop search 
engine and org-mode. Recoll's a powerful beast with lots of options 
(booleans, proximity search, stemming, date, directory, file type) and 
the ability to search your recently (Firefox) visited web sites as well 
as files on your own machine. And recoll can do this for an awful lot of 
document types including even pdf, ps and word docs:


http://www.lesbonscomptes.com/recoll/features.html

I've simply

1. Added an emacs function that calls recoll from emacs, allowing to 
send the word the cursor is on or enter a search from the minibuffer


2. Arranged for the search term and the results to be stored in a org 
file, with the results as links


3. Added a little more code so that you can select a search and update 
the results


I'll add the ability to update an entire page with a single click at 
some point - and possibly a way of having a page update when loaded.


The intended benefit is that users will be able to rapidly make indexes 
to collections of documents they've stored. (Which is something I'm 
prone to.)


So:

1. If anyone is interested in testing this, please let me know

2. I could do with an experienced elisp coder to review this when I've 
finished. Things seem to be working well, but this is my first time 
coding elisp, and the docs and I do *not* get on. If anyone feels like 
volunteering - there will probably only be around 100 LOC - please let 
me know.









[O] Writing .el files for org in org?

2014-05-21 Thread Rainer M Krug
Hi

I am just getting into the ob-R.el file and am making some changes which
will make it easier to customize the behaviour and possibly mre
transparent how variable transfer and wrapping of graph generation is
done.

But as I am struggling with elisp, I would like to put the ob-R.el file
into an org file which is then tangled into the ob-R.el file. this is
obviously possible, but I think that my comments and insight (from a
non-elisp programmers perspective) might be useful for others as well. I
could obviously put the ob-el.org file on github, but I am wondring if
it would be possible to include it into the org distribution, which then
could be tangled upon compile / installation?

I am sure this would be possible, but would this be feasible? A good
idea? Or would it be better to have an additional directory
(e.g. lisp.org) which contains the corresponding .org files?

For personal usage, I am going to use it, but it might be useful to have
this for all supported languages?

Cheers,

Rainer

-- 
Rainer M. Krug, PhD (Conservation Ecology, SUN), MSc (Conservation Biology, 
UCT), Dipl. Phys. (Germany)

Centre of Excellence for Invasion Biology
Stellenbosch University
South Africa

Tel :   +33 - (0)9 53 10 27 44
Cell:   +33 - (0)6 85 62 59 98
Fax :   +33 - (0)9 58 10 27 44

Fax (D):+49 - (0)3 21 21 25 22 44

email:  rai...@krugs.de

Skype:  RMkrug

PGP: 0x0F52F982


pgpsebTnKuGAY.pgp
Description: PGP signature


Re: [O] wish: provide flush_right/right_aligned text rendering directive

2014-05-21 Thread Nicolas Goaziou
Bastien b...@gnu.org writes:

 Yes -- I suggest we simply put this aside for the moment.

Well, actually it required more work than I thought. Here is the patch,
with some documentation. I didn't test it thoroughly, so feedback is
welcome.


Regards,

-- 
Nicolas Goaziou
From 744ee75b33ce1dea299626621558901d9ada09ef Mon Sep 17 00:00:00 2001
From: Nicolas Goaziou n.goaz...@gmail.com
Date: Wed, 21 May 2014 23:37:00 +0200
Subject: [PATCH] ox-ascii: Implement justifyright and justifyleft blocks

* lisp/ox-ascii.el
(org-ascii--justify-lines): New function.  Renamed from
`org-ascii--justify-string'.
(org-ascii--justify-element, org-ascii--current-justification): New
functions.
(org-ascii-verse-block, org-ascii-table-cell, org-ascii-table
  org-ascii-src-block, org-ascii-property-drawer, org-ascii-planning,
  org-ascii-paragraph, org-ascii-paragraph,
  org-ascii-latex-environment, org-ascii-horizontal-rule,
  org-ascii-fixed-width, org-ascii-export-block,
  org-ascii-example-block, org-ascii-clock, org-ascii-center-block,
  org-ascii-template--document-title,
  org-ascii-template--document-title): Use new functions.

* doc/org.texi (ASCII/Latin-1/UTF-8 export): Document new feature.

This patches also fixes centering of tables.
---
 doc/org.texi |  19 +
 lisp/ox-ascii.el | 227 +++
 2 files changed, 165 insertions(+), 81 deletions(-)

diff --git a/doc/org.texi b/doc/org.texi
index c685748..9cf0d7f 100644
--- a/doc/org.texi
+++ b/doc/org.texi
@@ -10804,6 +10804,25 @@ specified using an @code{ATTR_ASCII} line, directly preceding the rule.
 -
 @end example
 
+@subheading ASCII special blocks
+@cindex special blocks, in ASCII export
+@cindex #+BEGIN_JUSTIFYLEFT
+@cindex #+BEGIN_JUSTIFYRIGHT
+
+In addition to @code{#+BEGIN_CENTER} blocks (@pxref{Paragraphs}), it is
+possible to justify contents to the left or the right of the page with the
+following dedicated blocks.
+
+@example
+#+BEGIN_JUSTIFYLEFT
+It's just a jump to the left
+#+END_JUSTIFYLEFT
+
+#+BEGIN_JUSTIFYRIGHT
+And then a step to the right.
+#+END_JUSTIFYRIGHT
+@end example
+
 @node Beamer export
 @section Beamer export
 @cindex Beamer export
diff --git a/lisp/ox-ascii.el b/lisp/ox-ascii.el
index 858e3f0..b7ed268 100644
--- a/lisp/ox-ascii.el
+++ b/lisp/ox-ascii.el
@@ -385,14 +385,14 @@ nil to ignore the inline task.
 
 ;; Internal functions fall into three categories.
 
 ;; The first one is about text formatting.  The core function is
 ;; `org-ascii--current-text-width', which determines the current
 ;; text width allowed to a given element.  In other words, it helps
 ;; keeping each line width within maximum text width defined in
 ;; `org-ascii-text-width'.  Once this information is known,
 ;; `org-ascii--fill-string', `org-ascii--justify-string',
 ;; `org-ascii--box-string' and `org-ascii--indent-string' can
 ;; operate on a given output string.
 
 ;; The second category contains functions handling elements listings,
 ;; triggered by #+TOC: keyword.  As such, `org-ascii--build-toc'
@@ -421,7 +421,8 @@ a communication channel.
 Optional argument JUSTIFY can specify any type of justification
 among `left', `center', `right' or `full'.  A nil value is
 equivalent to `left'.  For a justification that doesn't also fill
-string, see `org-ascii--justify-string'.
+string, see `org-ascii--justify-lines' and
+`org-ascii--justify-block'.
 
 Return nil if S isn't a string.
   ;; Don't fill paragraph when break should be preserved.
@@ -436,8 +437,8 @@ Return nil if S isn't a string.
 		 (fill-region (point-min) (point-max) justify))
 	   (buffer-string))
 
-(defun org-ascii--justify-string (s text-width how)
-  Justify string S.
+(defun org-ascii--justify-lines (s text-width how)
+  Justify all lines in string S.
 TEXT-WIDTH is an integer specifying maximum length of a line.
 HOW determines the type of justification: it can be `left',
 `right', `full' or `center'.
@@ -453,6 +454,40 @@ HOW determines the type of justification: it can be `left',
 	(forward-line)))
 (buffer-string)))
 
+(defun org-ascii--justify-element (contents element info)
+  Justify CONTENTS of ELEMENT, as a block.
+INFO is a plist used as a communication channel.  Justification
+is done according to the widest non blank line in CONTENTS.  It
+is appropriate for regular (i.e, non-greater) elements, except
+paragraphs, which should be filled instead.
+  (if (not (org-string-nw-p contents)) contents
+(let ((text-width 
@@ -385,14 +385,14 @@ nil to ignore the inline task.
 ;; Internal functions fall into three categories.
 
-;; The first one is about text formatting.  The core function is
-;; `org-ascii--current-text-width', which determines the current
-;; text width allowed to a given element.  In other words, it helps
-;; keeping each line width within maximum text width defined in
-;; `org-ascii-text-width'.  Once this information is known,
-;; `org-ascii--fill-string', `org-ascii--justify-string',
-;; `org-ascii--box-string' and `org-ascii--indent-string' can
-;; operate on a given output string.
+;; The first one is about text formatting.  The core functions are
+;; `org-ascii--current-text-width' and
+;; `org-ascii--current-justification', which determine, respectively,
+;; the current text width allowed to a given element and its expected
+;; justification.  Once this information is known,
+;; `org-ascii--fill-string', `org-ascii--justify-lines',
+;; `org-ascii--justify-element' `org-ascii--box-string' and
+;; `org-ascii--indent-string' can operate on a given output string.
 
 ;; The second category contains functions handling elements listings,

Re: [O] Pandoc users, how do you use it with org-mode, and why?

2014-05-21 Thread Alan L Tyree
I'm using org-mode for a lengthy book. My editor has graciously agreed 
to edit the raw ord-mode files, thus eliminating yet another source of 
re-introduced errors.


However, the publisher asks her to format in Word, so after all the 
editing is done, I need to convert to Word. Pandoc seems a good choice:


org - latex - docx: the first step normal org export, the second step 
Pandoc.


It is good EXCEPT my book contains many, many cross references. In docx 
they come out looking like:


see [sec-3-4-2] when I want them to look like see 3.4.2.

I'm still on a steep part of the learning curve, so don't know if Pandoc 
can be tweaked to fix this. I have also tried oolatex which is a part of 
the tex4ht suite. It does the right thing on cross references, but has 
some other minor problems.


I have also used Pandoc to convert a friends Markdown to ePub. Slick and 
nice.


Cheers,
Alan

On 22/05/14 04:01, Grant Rettke wrote:

Hi,

Lately been hearing great things about Pandoc's ability to export to 
ebook formats and more.


Folks that use both Pandoc and org-mode: how do you use them together, 
and why?


Kind regards,

Grant Rettke | AAAS, ACM, ASA, FSF, IEEE, SIAM, Sigma Xi
g...@wisdomandwonder.com mailto:g...@wisdomandwonder.com | 
http://www.wisdomandwonder.com/

“Wisdom begins in wonder.” --Socrates
((λ (x) (x x)) (λ (x) (x x)))
“Life has become immeasurably better since I have been forced to stop 
taking it seriously.” --Thompson


--
Alan L Tyreehttp://www2.austlii.edu.au/~alan
Tel:  04 2748 6206  sip:typh...@iptel.org



Re: [O] latex export beginner

2014-05-21 Thread Steven Arntson
Success! I installed that package, and things are working. Thank you!
-steven

Igor Sosa Mayor joseleopoldo1...@gmail.com writes:

 Steven Arntson ste...@stevenarntson.com writes:

 Nick Dokos ndo...@gmail.com writes:


 well, it's pretty clear...

 ! LaTeX Error: File `wrapfig.sty' not found.

 you have to install the wrapfig package. If you're in debian/ubuntu:

 sudo apt-get install texlive-latex-extra




Re: [O] Writing .el files for org in org?

2014-05-21 Thread Aaron Ecay
Hi Rainer,

I have wondered about what you suggest as well, from the point of view
of trying to modify the long pieces of R code which are embedded in
strings in ob-R.el.  I think this would be easier if they could be
tangled from R code blocks in an org file.  So from that point of view
the idea has a +1 from me.

I am not so convinced that having all the elisp code in an org file
would be convenient, since I am worried that would break the interactive
features of elisp programming.  (edebug, find-function, paredit, ...).
But if you are doing the experiment, I would be glad to see what you
come up with: the benefits might turn out to be worth the potential
drawbacks.

--
Aaron Ecay



[O] Dated checkbox items

2014-05-21 Thread Sharon Kimble
In my todo list I have this as an entry
--8---cut here---start-8---
+ [ ] pick up bnf from the corner store2014-05-22 Thu
--8---cut here---end---8---

which appears like this in the agenda
--8---cut here---start-8---
  organiser:  Jobs to do [12/36] [33%]
--8---cut here---end---8---

How can the checkbox item be better dated such that it shows in the
agenda with a meaningful output please?

Thanks
Sharon.
-- 
A taste of linux = http://www.sharons.org.uk
my git repo = https://bitbucket.org/boudiccas/dots
TGmeds = http://www.tgmeds.org.uk
Debian testing, Fluxbox 1.3.5, emacs 24.3.91.1


signature.asc
Description: PGP signature


Re: [O] Desktop search for Org-Mode (linux/os-x). Looking for betas and code reviewers

2014-05-21 Thread Christian Wittern
Jonathan,

Sounds like an interesting project.  If you are ready, I'd like to have a look.

Cheers,  Christian



-- 
Christian Wittern, Kyoto



Re: [O] Writing .el files for org in org?

2014-05-21 Thread Grant Rettke
On Wed, May 21, 2014 at 3:21 PM, Rainer M Krug rai...@krugs.de wrote:
 I am sure this would be possible, but would this be feasible? A good
 idea? Or would it be better to have an additional directory
 (e.g. lisp.org) which contains the corresponding .org files?

Great question. Anybody tangling with org-mode has either already
asked themselves this question, or will be soon. When I started out
with org-mode I looked at it as a writing tool, and that was true
until I started using the literate programming feature. Without the
right perspective, I got myself into a lot of trouble. When I started
looking at it as programming, and system management, things started
working out for me again. When you frame your question more as a
systems management question, it gets a little clearer.

What does it take to release your code to production? The simplest
form would be to keep your generated files in Git, tag the release,
and then you are done. That is the official and final version of that
release of the system. Following this approach means that you can
release it easily on MELPA and org and anywhere else that you need
because you know what you generated, how you generated it, and how you
tested it. Simple. The alternative is to release only the source
org-file.

This process is a little more involved. In order to sign off on
allowing people to use the system that is built with that org file,
you need to make sure that they are able to regenerate it using
exactly the environment that you intend. For example, you will tangle
with a particular version of Emacs, on a particular platform, with a
particular set of plugins loaded into Emacs when you do the tangling.
Perhaps you even want to specify down to the operating system, and
more. Whether you intended it or not, the entirety of the system that
you use to do the tangling, is the implicit specification for what
people should use to tangle it themselves. Sure, I am going a bit
overboard here, but generally people don't care about such stuff until
it breaks.

My personal preference is to go with the latter. It forces me to know
what is going on. Doing it by hand is so tedious and often error prone
though, so I'm investing in mastering Vagrant. Vagrant will let you
have a reproducible system so you can specify what you used to build
your release (generate), and let others do that too if they want. The
only difficult is how lock that down for deployed code. Surely most of
the time you may just do the generation on deploy, eg via ELPA or its
kin. It just depends standard you want to, and must, hold yourself
too.

Safe travels.



Re: [O] (Bug)Open the attachment in the subheading in agenda view

2014-05-21 Thread Kyutech
Hi Bastien,

That helps!

I never no that properties before, thanks for your help!


On Thu, May 22, 2014 at 2:53 AM, Bastien b...@gnu.org wrote:

 Hi Kyutech,

 Kyutech lei-...@edu.life.kyutech.ac.jp writes:

  I have turned on the inheritance of the properties,

 Do you have a :ATTACH_DIR_INHERIT: t in the top heading you want the
 attachments to be inherited from?

 HTH,

 --
  Bastien



Re: [O] Can I create an agenda sorted manually keeping its order at refresh?

2014-05-21 Thread M
 Von: Samuel Wales samolog...@gmail.com
 Datum: Tue, 20 May 2014 13:49:51 -0700
 
 you can use, for example, priorities to indicate the order you want,
 and then refresh the agenda.
 

Hi Samuel,

thanks for your comment!
I do use priorities already, but they have a special meaning and can not be
changed spontaneously (in my system).
Even if a Prio-A task is more important or urgent than a B-task, there might
be reasons to do the B-task first.

I do use the priorities already for rough sorting of the tasks, but as there
much too many tasks, the few priority levels are not fine enough for real
sorting and it could be quite cumbersome to tweak that.

Martin
 





Re: [O] Can I create an agenda sorted manually keeping its order at refresh?

2014-05-21 Thread M



 Von: Bastien b...@gnu.org
 Datum: Tue, 20 May 2014 18:14:28 +0200
 I'd like to create an agenda view which is sorted manually so that I
 can put the things on the agenda in the order like I want to act on
 them and preserve this order even if the agenda is rebuilt or closed
 and created again.
  
 Is that possible already?
 
 Nope -- this would require to store information about this manual
 sorting *somewhere* when the agenda view is not present, i.e. in the
 headlines themselves, or in a place where we would put meta-data about
 the agenda views.
 
 The manual sorting is really for temporary convenience.
 

Hi Bastien,

thanks for your answer.
Could it be possible to ignore the predefined sorting order when refreshing
an existing agenda?

I just wondered what I do before refreshing ans why I do the refresh:
Some tasks on the list might have been done and should disappear, some might
be postponed by changing their SCHEDULED or DEADLINE date into the future
ans should disappear from the view after refresh.

Background: I have a block agenda with the tasks I should do at a certain
day, but sometimes (no: nearly always) there are too many, so that it is
overwhelming. They are sorted by priority and by a timestamp in several
blocks, but sometimes it would be nice to just set them manually in a
specific order which makes more sense (but I do not want to change the
priority flags).

Another alternative could be to
1) mark those tasks I want to sort manually for doing them first (with a tag
or a flag/star - does that exist in org-mode?)
2a) create a new agenda which collects only those marked tasks
3a) sort it manually (which leads to the same problem as above)

or
2a) create a temporary buffer whith headings that contain a hyperlink to
those marked tasks
3a) manually rearrange those headings

Kind regards

Martin 





[O] Beamer export: toggle export of select headlines/frames

2014-05-21 Thread Vikas Rawal
I am creating a beamer presentation, but want to be able to toggle inclusion or 
exclusion of some headlines/frames in the export, depending on the occasion 
where the presentation is being made. What is the appropriate way to do this?

I can use :no export: for selected headlines, but it would have been useful if 
I could have an easy way to switch.

Vikas